# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class FeedItemValidationErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class FeedItemValidationError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> FeedItemValidationErrorEnum.FeedItemValidationError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[FeedItemValidationErrorEnum.FeedItemValidationError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, FeedItemValidationErrorEnum.FeedItemValidationError]]: ...
        UNSPECIFIED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 0)
        UNKNOWN = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 1)
        STRING_TOO_SHORT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 2)
        STRING_TOO_LONG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 3)
        VALUE_NOT_SPECIFIED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 4)
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 5)
        INVALID_PHONE_NUMBER = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 6)
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 7)
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 8)
        DISALLOWED_NUMBER_TYPE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 9)
        VALUE_OUT_OF_RANGE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 10)
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 11)
        CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 12)
        INVALID_COUNTRY_CODE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 13)
        INVALID_APP_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 14)
        MISSING_ATTRIBUTES_FOR_FIELDS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 15)
        INVALID_TYPE_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 16)
        INVALID_EMAIL_ADDRESS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 17)
        INVALID_HTTPS_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 18)
        MISSING_DELIVERY_ADDRESS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 19)
        START_DATE_AFTER_END_DATE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 20)
        MISSING_FEED_ITEM_START_TIME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 21)
        MISSING_FEED_ITEM_END_TIME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 22)
        MISSING_FEED_ITEM_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 23)
        VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 24)
        INVALID_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 25)
        INVALID_NUMBER_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 26)
        INVALID_DATE_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 27)
        INVALID_PRICE_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 28)
        UNKNOWN_PLACEHOLDER_FIELD = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 29)
        MISSING_ENHANCED_SITELINK_DESCRIPTION_LINE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 30)
        REVIEW_EXTENSION_SOURCE_INELIGIBLE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 31)
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 32)
        DOUBLE_QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 33)
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 34)
        INVALID_FORM_ENCODED_PARAMS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 35)
        INVALID_URL_PARAMETER_NAME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 36)
        NO_GEOCODING_RESULT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 37)
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 38)
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 39)
        INVALID_PLACEHOLDER_FIELD_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 40)
        INVALID_URL_TAG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 41)
        LIST_TOO_LONG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 42)
        INVALID_ATTRIBUTES_COMBINATION = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 43)
        DUPLICATE_VALUES = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 44)
        INVALID_CALL_CONVERSION_ACTION_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 45)
        CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 46)
        APP_ID_DOESNT_EXIST_IN_APP_STORE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 47)
        INVALID_FINAL_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 48)
        INVALID_TRACKING_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 49)
        INVALID_FINAL_URL_FOR_APP_DOWNLOAD_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 50)
        LIST_TOO_SHORT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 51)
        INVALID_USER_ACTION = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 52)
        INVALID_TYPE_NAME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 53)
        INVALID_EVENT_CHANGE_STATUS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 54)
        INVALID_SNIPPETS_HEADER = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 55)
        INVALID_ANDROID_APP_LINK = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 56)
        NUMBER_TYPE_WITH_CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 57)
        RESERVED_KEYWORD_OTHER = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 58)
        DUPLICATE_OPTION_LABELS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 59)
        DUPLICATE_OPTION_PREFILLS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 60)
        UNEQUAL_LIST_LENGTHS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 61)
        INCONSISTENT_CURRENCY_CODES = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 62)
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 63)
        ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 64)
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 65)
        UNSUPPORTED_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 66)
        INVALID_FINAL_MOBILE_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 67)
        INVALID_KEYWORDLESS_AD_RULE_LABEL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 68)
        VALUE_TRACK_PARAMETER_NOT_SUPPORTED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 69)
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 70)
        INVALID_IOS_APP_LINK = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 71)
        MISSING_IOS_APP_LINK_OR_IOS_APP_STORE_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 72)
        PROMOTION_INVALID_TIME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 73)
        PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 74)
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 75)
        TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 76)
        AD_CUSTOMIZERS_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 77)
        INVALID_LANGUAGE_CODE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 78)
        UNSUPPORTED_LANGUAGE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 79)
        IF_FUNCTION_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 80)
        INVALID_FINAL_URL_SUFFIX = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 81)
        INVALID_TAG_IN_FINAL_URL_SUFFIX = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 82)
        INVALID_FINAL_URL_SUFFIX_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 83)
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 84)
        ONLY_ONE_DELIVERY_OPTION_IS_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 85)
        NO_DELIVERY_OPTION_IS_SET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 86)
        INVALID_CONVERSION_REPORTING_STATE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 87)
        IMAGE_SIZE_WRONG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 88)
        EMAIL_DELIVERY_NOT_AVAILABLE_IN_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 89)
        AUTO_REPLY_NOT_AVAILABLE_IN_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 90)
        INVALID_LATITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 91)
        INVALID_LONGITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 92)
        TOO_MANY_LABELS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 93)
        INVALID_IMAGE_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 94)
        MISSING_LATITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 95)
        MISSING_LONGITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 96)
        ADDRESS_NOT_FOUND = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 97)
        ADDRESS_NOT_TARGETABLE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 98)
    UNSPECIFIED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 0)
    UNKNOWN = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 1)
    STRING_TOO_SHORT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 2)
    STRING_TOO_LONG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 3)
    VALUE_NOT_SPECIFIED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 4)
    INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 5)
    INVALID_PHONE_NUMBER = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 6)
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 7)
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 8)
    DISALLOWED_NUMBER_TYPE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 9)
    VALUE_OUT_OF_RANGE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 10)
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 11)
    CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 12)
    INVALID_COUNTRY_CODE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 13)
    INVALID_APP_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 14)
    MISSING_ATTRIBUTES_FOR_FIELDS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 15)
    INVALID_TYPE_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 16)
    INVALID_EMAIL_ADDRESS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 17)
    INVALID_HTTPS_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 18)
    MISSING_DELIVERY_ADDRESS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 19)
    START_DATE_AFTER_END_DATE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 20)
    MISSING_FEED_ITEM_START_TIME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 21)
    MISSING_FEED_ITEM_END_TIME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 22)
    MISSING_FEED_ITEM_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 23)
    VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 24)
    INVALID_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 25)
    INVALID_NUMBER_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 26)
    INVALID_DATE_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 27)
    INVALID_PRICE_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 28)
    UNKNOWN_PLACEHOLDER_FIELD = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 29)
    MISSING_ENHANCED_SITELINK_DESCRIPTION_LINE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 30)
    REVIEW_EXTENSION_SOURCE_INELIGIBLE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 31)
    HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 32)
    DOUBLE_QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 33)
    QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 34)
    INVALID_FORM_ENCODED_PARAMS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 35)
    INVALID_URL_PARAMETER_NAME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 36)
    NO_GEOCODING_RESULT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 37)
    SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 38)
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 39)
    INVALID_PLACEHOLDER_FIELD_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 40)
    INVALID_URL_TAG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 41)
    LIST_TOO_LONG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 42)
    INVALID_ATTRIBUTES_COMBINATION = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 43)
    DUPLICATE_VALUES = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 44)
    INVALID_CALL_CONVERSION_ACTION_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 45)
    CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 46)
    APP_ID_DOESNT_EXIST_IN_APP_STORE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 47)
    INVALID_FINAL_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 48)
    INVALID_TRACKING_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 49)
    INVALID_FINAL_URL_FOR_APP_DOWNLOAD_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 50)
    LIST_TOO_SHORT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 51)
    INVALID_USER_ACTION = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 52)
    INVALID_TYPE_NAME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 53)
    INVALID_EVENT_CHANGE_STATUS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 54)
    INVALID_SNIPPETS_HEADER = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 55)
    INVALID_ANDROID_APP_LINK = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 56)
    NUMBER_TYPE_WITH_CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 57)
    RESERVED_KEYWORD_OTHER = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 58)
    DUPLICATE_OPTION_LABELS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 59)
    DUPLICATE_OPTION_PREFILLS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 60)
    UNEQUAL_LIST_LENGTHS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 61)
    INCONSISTENT_CURRENCY_CODES = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 62)
    PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 63)
    ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 64)
    PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 65)
    UNSUPPORTED_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 66)
    INVALID_FINAL_MOBILE_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 67)
    INVALID_KEYWORDLESS_AD_RULE_LABEL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 68)
    VALUE_TRACK_PARAMETER_NOT_SUPPORTED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 69)
    UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 70)
    INVALID_IOS_APP_LINK = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 71)
    MISSING_IOS_APP_LINK_OR_IOS_APP_STORE_ID = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 72)
    PROMOTION_INVALID_TIME = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 73)
    PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 74)
    PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 75)
    TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 76)
    AD_CUSTOMIZERS_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 77)
    INVALID_LANGUAGE_CODE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 78)
    UNSUPPORTED_LANGUAGE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 79)
    IF_FUNCTION_NOT_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 80)
    INVALID_FINAL_URL_SUFFIX = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 81)
    INVALID_TAG_IN_FINAL_URL_SUFFIX = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 82)
    INVALID_FINAL_URL_SUFFIX_FORMAT = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 83)
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 84)
    ONLY_ONE_DELIVERY_OPTION_IS_ALLOWED = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 85)
    NO_DELIVERY_OPTION_IS_SET = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 86)
    INVALID_CONVERSION_REPORTING_STATE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 87)
    IMAGE_SIZE_WRONG = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 88)
    EMAIL_DELIVERY_NOT_AVAILABLE_IN_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 89)
    AUTO_REPLY_NOT_AVAILABLE_IN_COUNTRY = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 90)
    INVALID_LATITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 91)
    INVALID_LONGITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 92)
    TOO_MANY_LABELS = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 93)
    INVALID_IMAGE_URL = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 94)
    MISSING_LATITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 95)
    MISSING_LONGITUDE_VALUE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 96)
    ADDRESS_NOT_FOUND = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 97)
    ADDRESS_NOT_TARGETABLE = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationError, 98)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedItemValidationErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ExtensionSettingErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ExtensionSettingError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ExtensionSettingErrorEnum.ExtensionSettingError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ExtensionSettingErrorEnum.ExtensionSettingError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ExtensionSettingErrorEnum.ExtensionSettingError]]: ...
        UNSPECIFIED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 0)
        UNKNOWN = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 1)
        EXTENSIONS_REQUIRED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 2)
        FEED_TYPE_EXTENSION_TYPE_MISMATCH = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 3)
        INVALID_FEED_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 4)
        INVALID_FEED_TYPE_FOR_CUSTOMER_EXTENSION_SETTING = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 5)
        CANNOT_CHANGE_FEED_ITEM_ON_CREATE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 6)
        CANNOT_UPDATE_NEWLY_CREATED_EXTENSION = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 7)
        NO_EXISTING_AD_GROUP_EXTENSION_SETTING_FOR_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 8)
        NO_EXISTING_CAMPAIGN_EXTENSION_SETTING_FOR_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 9)
        NO_EXISTING_CUSTOMER_EXTENSION_SETTING_FOR_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 10)
        AD_GROUP_EXTENSION_SETTING_ALREADY_EXISTS = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 11)
        CAMPAIGN_EXTENSION_SETTING_ALREADY_EXISTS = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 12)
        CUSTOMER_EXTENSION_SETTING_ALREADY_EXISTS = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 13)
        AD_GROUP_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 14)
        CAMPAIGN_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 15)
        CUSTOMER_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 16)
        VALUE_OUT_OF_RANGE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 17)
        CANNOT_SET_FIELD_WITH_FINAL_URLS = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 18)
        FINAL_URLS_NOT_SET = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 19)
        INVALID_PHONE_NUMBER = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 20)
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 21)
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 22)
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 23)
        DISALLOWED_NUMBER_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 24)
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 25)
        VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 26)
        INVALID_COUNTRY_CODE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 27)
        INVALID_CALL_CONVERSION_TYPE_ID = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 28)
        CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 29)
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 30)
        INVALID_APP_ID = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 31)
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 32)
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 33)
        REVIEW_EXTENSION_SOURCE_NOT_ELIGIBLE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 34)
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 35)
        MISSING_FIELD = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 36)
        INCONSISTENT_CURRENCY_CODES = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 37)
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 38)
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 39)
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 40)
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 41)
        UNSUPPORTED_VALUE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 42)
        INVALID_DEVICE_PREFERENCE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 43)
        INVALID_SCHEDULE_END = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 45)
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 47)
        OVERLAPPING_SCHEDULES_NOT_ALLOWED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 48)
        SCHEDULE_END_NOT_AFTER_START = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 49)
        TOO_MANY_SCHEDULES_PER_DAY = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 50)
        DUPLICATE_EXTENSION_FEED_ITEM_EDIT = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 51)
        INVALID_SNIPPETS_HEADER = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 52)
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 53)
        CAMPAIGN_TARGETING_MISMATCH = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 54)
        CANNOT_OPERATE_ON_REMOVED_FEED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 55)
        EXTENSION_TYPE_REQUIRED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 56)
        INCOMPATIBLE_UNDERLYING_MATCHING_FUNCTION = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 57)
        START_DATE_AFTER_END_DATE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 58)
        INVALID_PRICE_FORMAT = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 59)
        PROMOTION_INVALID_TIME = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 60)
        PROMOTION_CANNOT_SET_PERCENT_DISCOUNT_AND_MONEY_DISCOUNT = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 61)
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 62)
        TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 63)
        INVALID_LANGUAGE_CODE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 64)
        UNSUPPORTED_LANGUAGE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 65)
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 66)
        EXTENSION_SETTING_UPDATE_IS_A_NOOP = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 67)
    UNSPECIFIED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 0)
    UNKNOWN = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 1)
    EXTENSIONS_REQUIRED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 2)
    FEED_TYPE_EXTENSION_TYPE_MISMATCH = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 3)
    INVALID_FEED_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 4)
    INVALID_FEED_TYPE_FOR_CUSTOMER_EXTENSION_SETTING = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 5)
    CANNOT_CHANGE_FEED_ITEM_ON_CREATE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 6)
    CANNOT_UPDATE_NEWLY_CREATED_EXTENSION = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 7)
    NO_EXISTING_AD_GROUP_EXTENSION_SETTING_FOR_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 8)
    NO_EXISTING_CAMPAIGN_EXTENSION_SETTING_FOR_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 9)
    NO_EXISTING_CUSTOMER_EXTENSION_SETTING_FOR_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 10)
    AD_GROUP_EXTENSION_SETTING_ALREADY_EXISTS = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 11)
    CAMPAIGN_EXTENSION_SETTING_ALREADY_EXISTS = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 12)
    CUSTOMER_EXTENSION_SETTING_ALREADY_EXISTS = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 13)
    AD_GROUP_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 14)
    CAMPAIGN_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 15)
    CUSTOMER_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 16)
    VALUE_OUT_OF_RANGE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 17)
    CANNOT_SET_FIELD_WITH_FINAL_URLS = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 18)
    FINAL_URLS_NOT_SET = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 19)
    INVALID_PHONE_NUMBER = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 20)
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 21)
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 22)
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 23)
    DISALLOWED_NUMBER_TYPE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 24)
    INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 25)
    VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 26)
    INVALID_COUNTRY_CODE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 27)
    INVALID_CALL_CONVERSION_TYPE_ID = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 28)
    CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 29)
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 30)
    INVALID_APP_ID = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 31)
    QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 32)
    HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 33)
    REVIEW_EXTENSION_SOURCE_NOT_ELIGIBLE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 34)
    SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 35)
    MISSING_FIELD = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 36)
    INCONSISTENT_CURRENCY_CODES = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 37)
    PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 38)
    PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 39)
    PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 40)
    PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 41)
    UNSUPPORTED_VALUE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 42)
    INVALID_DEVICE_PREFERENCE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 43)
    INVALID_SCHEDULE_END = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 45)
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 47)
    OVERLAPPING_SCHEDULES_NOT_ALLOWED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 48)
    SCHEDULE_END_NOT_AFTER_START = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 49)
    TOO_MANY_SCHEDULES_PER_DAY = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 50)
    DUPLICATE_EXTENSION_FEED_ITEM_EDIT = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 51)
    INVALID_SNIPPETS_HEADER = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 52)
    PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 53)
    CAMPAIGN_TARGETING_MISMATCH = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 54)
    CANNOT_OPERATE_ON_REMOVED_FEED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 55)
    EXTENSION_TYPE_REQUIRED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 56)
    INCOMPATIBLE_UNDERLYING_MATCHING_FUNCTION = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 57)
    START_DATE_AFTER_END_DATE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 58)
    INVALID_PRICE_FORMAT = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 59)
    PROMOTION_INVALID_TIME = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 60)
    PROMOTION_CANNOT_SET_PERCENT_DISCOUNT_AND_MONEY_DISCOUNT = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 61)
    PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 62)
    TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 63)
    INVALID_LANGUAGE_CODE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 64)
    UNSUPPORTED_LANGUAGE = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 65)
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 66)
    EXTENSION_SETTING_UPDATE_IS_A_NOOP = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingError, 67)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ExtensionSettingErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.asset_types_pb2 import (
    ImageAsset as google___ads___googleads___v2___common___asset_types_pb2___ImageAsset,
    MediaBundleAsset as google___ads___googleads___v2___common___asset_types_pb2___MediaBundleAsset,
    TextAsset as google___ads___googleads___v2___common___asset_types_pb2___TextAsset,
    YoutubeVideoAsset as google___ads___googleads___v2___common___asset_types_pb2___YoutubeVideoAsset,
)

from google.ads.google_ads.v2.proto.enums.asset_type_pb2 import (
    AssetTypeEnum as google___ads___googleads___v2___enums___asset_type_pb2___AssetTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class Asset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    type = ... # type: google___ads___googleads___v2___enums___asset_type_pb2___AssetTypeEnum.AssetType

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def youtube_video_asset(self) -> google___ads___googleads___v2___common___asset_types_pb2___YoutubeVideoAsset: ...

    @property
    def media_bundle_asset(self) -> google___ads___googleads___v2___common___asset_types_pb2___MediaBundleAsset: ...

    @property
    def image_asset(self) -> google___ads___googleads___v2___common___asset_types_pb2___ImageAsset: ...

    @property
    def text_asset(self) -> google___ads___googleads___v2___common___asset_types_pb2___TextAsset: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        type : typing___Optional[google___ads___googleads___v2___enums___asset_type_pb2___AssetTypeEnum.AssetType] = None,
        youtube_video_asset : typing___Optional[google___ads___googleads___v2___common___asset_types_pb2___YoutubeVideoAsset] = None,
        media_bundle_asset : typing___Optional[google___ads___googleads___v2___common___asset_types_pb2___MediaBundleAsset] = None,
        image_asset : typing___Optional[google___ads___googleads___v2___common___asset_types_pb2___ImageAsset] = None,
        text_asset : typing___Optional[google___ads___googleads___v2___common___asset_types_pb2___TextAsset] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Asset: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"asset_data",u"id",u"image_asset",u"media_bundle_asset",u"name",u"text_asset",u"youtube_video_asset"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"asset_data",u"id",u"image_asset",u"media_bundle_asset",u"name",u"resource_name",u"text_asset",u"type",u"youtube_video_asset"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"asset_data",b"asset_data",u"id",b"id",u"image_asset",b"image_asset",u"media_bundle_asset",b"media_bundle_asset",u"name",b"name",u"text_asset",b"text_asset",u"youtube_video_asset",b"youtube_video_asset"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"asset_data",b"asset_data",u"id",b"id",u"image_asset",b"image_asset",u"media_bundle_asset",b"media_bundle_asset",u"name",b"name",u"resource_name",b"resource_name",u"text_asset",b"text_asset",u"type",b"type",u"youtube_video_asset",b"youtube_video_asset"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"asset_data",b"asset_data"]) -> typing_extensions___Literal["youtube_video_asset","media_bundle_asset","image_asset","text_asset"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class MediaBundleErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class MediaBundleError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> MediaBundleErrorEnum.MediaBundleError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[MediaBundleErrorEnum.MediaBundleError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, MediaBundleErrorEnum.MediaBundleError]]: ...
        UNSPECIFIED = typing___cast(MediaBundleErrorEnum.MediaBundleError, 0)
        UNKNOWN = typing___cast(MediaBundleErrorEnum.MediaBundleError, 1)
        BAD_REQUEST = typing___cast(MediaBundleErrorEnum.MediaBundleError, 3)
        DOUBLECLICK_BUNDLE_NOT_ALLOWED = typing___cast(MediaBundleErrorEnum.MediaBundleError, 4)
        EXTERNAL_URL_NOT_ALLOWED = typing___cast(MediaBundleErrorEnum.MediaBundleError, 5)
        FILE_TOO_LARGE = typing___cast(MediaBundleErrorEnum.MediaBundleError, 6)
        GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = typing___cast(MediaBundleErrorEnum.MediaBundleError, 7)
        INVALID_INPUT = typing___cast(MediaBundleErrorEnum.MediaBundleError, 8)
        INVALID_MEDIA_BUNDLE = typing___cast(MediaBundleErrorEnum.MediaBundleError, 9)
        INVALID_MEDIA_BUNDLE_ENTRY = typing___cast(MediaBundleErrorEnum.MediaBundleError, 10)
        INVALID_MIME_TYPE = typing___cast(MediaBundleErrorEnum.MediaBundleError, 11)
        INVALID_PATH = typing___cast(MediaBundleErrorEnum.MediaBundleError, 12)
        INVALID_URL_REFERENCE = typing___cast(MediaBundleErrorEnum.MediaBundleError, 13)
        MEDIA_DATA_TOO_LARGE = typing___cast(MediaBundleErrorEnum.MediaBundleError, 14)
        MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = typing___cast(MediaBundleErrorEnum.MediaBundleError, 15)
        SERVER_ERROR = typing___cast(MediaBundleErrorEnum.MediaBundleError, 16)
        STORAGE_ERROR = typing___cast(MediaBundleErrorEnum.MediaBundleError, 17)
        SWIFFY_BUNDLE_NOT_ALLOWED = typing___cast(MediaBundleErrorEnum.MediaBundleError, 18)
        TOO_MANY_FILES = typing___cast(MediaBundleErrorEnum.MediaBundleError, 19)
        UNEXPECTED_SIZE = typing___cast(MediaBundleErrorEnum.MediaBundleError, 20)
        UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = typing___cast(MediaBundleErrorEnum.MediaBundleError, 21)
        UNSUPPORTED_HTML5_FEATURE = typing___cast(MediaBundleErrorEnum.MediaBundleError, 22)
        URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = typing___cast(MediaBundleErrorEnum.MediaBundleError, 23)
        CUSTOM_EXIT_NOT_ALLOWED = typing___cast(MediaBundleErrorEnum.MediaBundleError, 24)
    UNSPECIFIED = typing___cast(MediaBundleErrorEnum.MediaBundleError, 0)
    UNKNOWN = typing___cast(MediaBundleErrorEnum.MediaBundleError, 1)
    BAD_REQUEST = typing___cast(MediaBundleErrorEnum.MediaBundleError, 3)
    DOUBLECLICK_BUNDLE_NOT_ALLOWED = typing___cast(MediaBundleErrorEnum.MediaBundleError, 4)
    EXTERNAL_URL_NOT_ALLOWED = typing___cast(MediaBundleErrorEnum.MediaBundleError, 5)
    FILE_TOO_LARGE = typing___cast(MediaBundleErrorEnum.MediaBundleError, 6)
    GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = typing___cast(MediaBundleErrorEnum.MediaBundleError, 7)
    INVALID_INPUT = typing___cast(MediaBundleErrorEnum.MediaBundleError, 8)
    INVALID_MEDIA_BUNDLE = typing___cast(MediaBundleErrorEnum.MediaBundleError, 9)
    INVALID_MEDIA_BUNDLE_ENTRY = typing___cast(MediaBundleErrorEnum.MediaBundleError, 10)
    INVALID_MIME_TYPE = typing___cast(MediaBundleErrorEnum.MediaBundleError, 11)
    INVALID_PATH = typing___cast(MediaBundleErrorEnum.MediaBundleError, 12)
    INVALID_URL_REFERENCE = typing___cast(MediaBundleErrorEnum.MediaBundleError, 13)
    MEDIA_DATA_TOO_LARGE = typing___cast(MediaBundleErrorEnum.MediaBundleError, 14)
    MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = typing___cast(MediaBundleErrorEnum.MediaBundleError, 15)
    SERVER_ERROR = typing___cast(MediaBundleErrorEnum.MediaBundleError, 16)
    STORAGE_ERROR = typing___cast(MediaBundleErrorEnum.MediaBundleError, 17)
    SWIFFY_BUNDLE_NOT_ALLOWED = typing___cast(MediaBundleErrorEnum.MediaBundleError, 18)
    TOO_MANY_FILES = typing___cast(MediaBundleErrorEnum.MediaBundleError, 19)
    UNEXPECTED_SIZE = typing___cast(MediaBundleErrorEnum.MediaBundleError, 20)
    UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = typing___cast(MediaBundleErrorEnum.MediaBundleError, 21)
    UNSUPPORTED_HTML5_FEATURE = typing___cast(MediaBundleErrorEnum.MediaBundleError, 22)
    URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = typing___cast(MediaBundleErrorEnum.MediaBundleError, 23)
    CUSTOM_EXIT_NOT_ALLOWED = typing___cast(MediaBundleErrorEnum.MediaBundleError, 24)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MediaBundleErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.criteria_pb2 import (
    KeywordInfo as google___ads___googleads___v2___common___criteria_pb2___KeywordInfo,
)

from google.ads.google_ads.v2.proto.enums.ad_network_type_pb2 import (
    AdNetworkTypeEnum as google___ads___googleads___v2___enums___ad_network_type_pb2___AdNetworkTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.click_type_pb2 import (
    ClickTypeEnum as google___ads___googleads___v2___enums___click_type_pb2___ClickTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.conversion_action_category_pb2 import (
    ConversionActionCategoryEnum as google___ads___googleads___v2___enums___conversion_action_category_pb2___ConversionActionCategoryEnum,
)

from google.ads.google_ads.v2.proto.enums.conversion_attribution_event_type_pb2 import (
    ConversionAttributionEventTypeEnum as google___ads___googleads___v2___enums___conversion_attribution_event_type_pb2___ConversionAttributionEventTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.conversion_lag_bucket_pb2 import (
    ConversionLagBucketEnum as google___ads___googleads___v2___enums___conversion_lag_bucket_pb2___ConversionLagBucketEnum,
)

from google.ads.google_ads.v2.proto.enums.conversion_or_adjustment_lag_bucket_pb2 import (
    ConversionOrAdjustmentLagBucketEnum as google___ads___googleads___v2___enums___conversion_or_adjustment_lag_bucket_pb2___ConversionOrAdjustmentLagBucketEnum,
)

from google.ads.google_ads.v2.proto.enums.day_of_week_pb2 import (
    DayOfWeekEnum as google___ads___googleads___v2___enums___day_of_week_pb2___DayOfWeekEnum,
)

from google.ads.google_ads.v2.proto.enums.device_pb2 import (
    DeviceEnum as google___ads___googleads___v2___enums___device_pb2___DeviceEnum,
)

from google.ads.google_ads.v2.proto.enums.external_conversion_source_pb2 import (
    ExternalConversionSourceEnum as google___ads___googleads___v2___enums___external_conversion_source_pb2___ExternalConversionSourceEnum,
)

from google.ads.google_ads.v2.proto.enums.hotel_date_selection_type_pb2 import (
    HotelDateSelectionTypeEnum as google___ads___googleads___v2___enums___hotel_date_selection_type_pb2___HotelDateSelectionTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.hotel_price_bucket_pb2 import (
    HotelPriceBucketEnum as google___ads___googleads___v2___enums___hotel_price_bucket_pb2___HotelPriceBucketEnum,
)

from google.ads.google_ads.v2.proto.enums.hotel_rate_type_pb2 import (
    HotelRateTypeEnum as google___ads___googleads___v2___enums___hotel_rate_type_pb2___HotelRateTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.month_of_year_pb2 import (
    MonthOfYearEnum as google___ads___googleads___v2___enums___month_of_year_pb2___MonthOfYearEnum,
)

from google.ads.google_ads.v2.proto.enums.placeholder_type_pb2 import (
    PlaceholderTypeEnum as google___ads___googleads___v2___enums___placeholder_type_pb2___PlaceholderTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.product_channel_exclusivity_pb2 import (
    ProductChannelExclusivityEnum as google___ads___googleads___v2___enums___product_channel_exclusivity_pb2___ProductChannelExclusivityEnum,
)

from google.ads.google_ads.v2.proto.enums.product_channel_pb2 import (
    ProductChannelEnum as google___ads___googleads___v2___enums___product_channel_pb2___ProductChannelEnum,
)

from google.ads.google_ads.v2.proto.enums.product_condition_pb2 import (
    ProductConditionEnum as google___ads___googleads___v2___enums___product_condition_pb2___ProductConditionEnum,
)

from google.ads.google_ads.v2.proto.enums.search_engine_results_page_type_pb2 import (
    SearchEngineResultsPageTypeEnum as google___ads___googleads___v2___enums___search_engine_results_page_type_pb2___SearchEngineResultsPageTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.search_term_match_type_pb2 import (
    SearchTermMatchTypeEnum as google___ads___googleads___v2___enums___search_term_match_type_pb2___SearchTermMatchTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.slot_pb2 import (
    SlotEnum as google___ads___googleads___v2___enums___slot_pb2___SlotEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int32Value as google___protobuf___wrappers_pb2___Int32Value,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
    UInt64Value as google___protobuf___wrappers_pb2___UInt64Value,
)

from typing import (
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class Segments(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ad_network_type = ... # type: google___ads___googleads___v2___enums___ad_network_type_pb2___AdNetworkTypeEnum.AdNetworkType
    click_type = ... # type: google___ads___googleads___v2___enums___click_type_pb2___ClickTypeEnum.ClickType
    conversion_action_category = ... # type: google___ads___googleads___v2___enums___conversion_action_category_pb2___ConversionActionCategoryEnum.ConversionActionCategory
    conversion_attribution_event_type = ... # type: google___ads___googleads___v2___enums___conversion_attribution_event_type_pb2___ConversionAttributionEventTypeEnum.ConversionAttributionEventType
    conversion_lag_bucket = ... # type: google___ads___googleads___v2___enums___conversion_lag_bucket_pb2___ConversionLagBucketEnum.ConversionLagBucket
    conversion_or_adjustment_lag_bucket = ... # type: google___ads___googleads___v2___enums___conversion_or_adjustment_lag_bucket_pb2___ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket
    day_of_week = ... # type: google___ads___googleads___v2___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeek
    device = ... # type: google___ads___googleads___v2___enums___device_pb2___DeviceEnum.Device
    external_conversion_source = ... # type: google___ads___googleads___v2___enums___external_conversion_source_pb2___ExternalConversionSourceEnum.ExternalConversionSource
    hotel_check_in_day_of_week = ... # type: google___ads___googleads___v2___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeek
    hotel_date_selection_type = ... # type: google___ads___googleads___v2___enums___hotel_date_selection_type_pb2___HotelDateSelectionTypeEnum.HotelDateSelectionType
    hotel_rate_type = ... # type: google___ads___googleads___v2___enums___hotel_rate_type_pb2___HotelRateTypeEnum.HotelRateType
    hotel_price_bucket = ... # type: google___ads___googleads___v2___enums___hotel_price_bucket_pb2___HotelPriceBucketEnum.HotelPriceBucket
    month_of_year = ... # type: google___ads___googleads___v2___enums___month_of_year_pb2___MonthOfYearEnum.MonthOfYear
    placeholder_type = ... # type: google___ads___googleads___v2___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderType
    product_channel = ... # type: google___ads___googleads___v2___enums___product_channel_pb2___ProductChannelEnum.ProductChannel
    product_channel_exclusivity = ... # type: google___ads___googleads___v2___enums___product_channel_exclusivity_pb2___ProductChannelExclusivityEnum.ProductChannelExclusivity
    product_condition = ... # type: google___ads___googleads___v2___enums___product_condition_pb2___ProductConditionEnum.ProductCondition
    search_engine_results_page_type = ... # type: google___ads___googleads___v2___enums___search_engine_results_page_type_pb2___SearchEngineResultsPageTypeEnum.SearchEngineResultsPageType
    search_term_match_type = ... # type: google___ads___googleads___v2___enums___search_term_match_type_pb2___SearchTermMatchTypeEnum.SearchTermMatchType
    slot = ... # type: google___ads___googleads___v2___enums___slot_pb2___SlotEnum.Slot

    @property
    def conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conversion_action_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conversion_adjustment(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_airport(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_canton(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_city(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_country(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_county(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_district(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_metro(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_most_specific_location(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_postal_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_province(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_region(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_state(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def hotel_booking_window_days(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def hotel_center_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def hotel_check_in_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def hotel_city(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def hotel_class(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

    @property
    def hotel_country(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def hotel_length_of_stay(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

    @property
    def hotel_rate_rule_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def hotel_state(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def hour(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

    @property
    def interaction_on_this_extension(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def keyword(self) -> Keyword: ...

    @property
    def month(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def partner_hotel_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_aggregator_id(self) -> google___protobuf___wrappers_pb2___UInt64Value: ...

    @property
    def product_bidding_category_level1(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_bidding_category_level2(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_bidding_category_level3(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_bidding_category_level4(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_bidding_category_level5(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_brand(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_country(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_custom_attribute0(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_custom_attribute1(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_custom_attribute2(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_custom_attribute3(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_custom_attribute4(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_item_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_language(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_merchant_id(self) -> google___protobuf___wrappers_pb2___UInt64Value: ...

    @property
    def product_store_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_title(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_type_l1(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_type_l2(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_type_l3(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_type_l4(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_type_l5(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def quarter(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def webpage(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def week(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def year(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

    def __init__(self,
        *,
        ad_network_type : typing___Optional[google___ads___googleads___v2___enums___ad_network_type_pb2___AdNetworkTypeEnum.AdNetworkType] = None,
        click_type : typing___Optional[google___ads___googleads___v2___enums___click_type_pb2___ClickTypeEnum.ClickType] = None,
        conversion_action : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_action_category : typing___Optional[google___ads___googleads___v2___enums___conversion_action_category_pb2___ConversionActionCategoryEnum.ConversionActionCategory] = None,
        conversion_action_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_adjustment : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        conversion_attribution_event_type : typing___Optional[google___ads___googleads___v2___enums___conversion_attribution_event_type_pb2___ConversionAttributionEventTypeEnum.ConversionAttributionEventType] = None,
        conversion_lag_bucket : typing___Optional[google___ads___googleads___v2___enums___conversion_lag_bucket_pb2___ConversionLagBucketEnum.ConversionLagBucket] = None,
        conversion_or_adjustment_lag_bucket : typing___Optional[google___ads___googleads___v2___enums___conversion_or_adjustment_lag_bucket_pb2___ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket] = None,
        date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        day_of_week : typing___Optional[google___ads___googleads___v2___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeek] = None,
        device : typing___Optional[google___ads___googleads___v2___enums___device_pb2___DeviceEnum.Device] = None,
        external_conversion_source : typing___Optional[google___ads___googleads___v2___enums___external_conversion_source_pb2___ExternalConversionSourceEnum.ExternalConversionSource] = None,
        geo_target_airport : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_canton : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_city : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_country : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_county : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_district : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_metro : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_most_specific_location : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_postal_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_province : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_region : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_state : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        hotel_booking_window_days : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        hotel_center_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        hotel_check_in_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        hotel_check_in_day_of_week : typing___Optional[google___ads___googleads___v2___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeek] = None,
        hotel_city : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        hotel_class : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
        hotel_country : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        hotel_date_selection_type : typing___Optional[google___ads___googleads___v2___enums___hotel_date_selection_type_pb2___HotelDateSelectionTypeEnum.HotelDateSelectionType] = None,
        hotel_length_of_stay : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
        hotel_rate_rule_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        hotel_rate_type : typing___Optional[google___ads___googleads___v2___enums___hotel_rate_type_pb2___HotelRateTypeEnum.HotelRateType] = None,
        hotel_price_bucket : typing___Optional[google___ads___googleads___v2___enums___hotel_price_bucket_pb2___HotelPriceBucketEnum.HotelPriceBucket] = None,
        hotel_state : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        hour : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
        interaction_on_this_extension : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        keyword : typing___Optional[Keyword] = None,
        month : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        month_of_year : typing___Optional[google___ads___googleads___v2___enums___month_of_year_pb2___MonthOfYearEnum.MonthOfYear] = None,
        partner_hotel_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        placeholder_type : typing___Optional[google___ads___googleads___v2___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderType] = None,
        product_aggregator_id : typing___Optional[google___protobuf___wrappers_pb2___UInt64Value] = None,
        product_bidding_category_level1 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_bidding_category_level2 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_bidding_category_level3 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_bidding_category_level4 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_bidding_category_level5 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_brand : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_channel : typing___Optional[google___ads___googleads___v2___enums___product_channel_pb2___ProductChannelEnum.ProductChannel] = None,
        product_channel_exclusivity : typing___Optional[google___ads___googleads___v2___enums___product_channel_exclusivity_pb2___ProductChannelExclusivityEnum.ProductChannelExclusivity] = None,
        product_condition : typing___Optional[google___ads___googleads___v2___enums___product_condition_pb2___ProductConditionEnum.ProductCondition] = None,
        product_country : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_custom_attribute0 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_custom_attribute1 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_custom_attribute2 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_custom_attribute3 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_custom_attribute4 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_item_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_language : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_merchant_id : typing___Optional[google___protobuf___wrappers_pb2___UInt64Value] = None,
        product_store_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_title : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_type_l1 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_type_l2 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_type_l3 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_type_l4 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_type_l5 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        quarter : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        search_engine_results_page_type : typing___Optional[google___ads___googleads___v2___enums___search_engine_results_page_type_pb2___SearchEngineResultsPageTypeEnum.SearchEngineResultsPageType] = None,
        search_term_match_type : typing___Optional[google___ads___googleads___v2___enums___search_term_match_type_pb2___SearchTermMatchTypeEnum.SearchTermMatchType] = None,
        slot : typing___Optional[google___ads___googleads___v2___enums___slot_pb2___SlotEnum.Slot] = None,
        webpage : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        week : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        year : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Segments: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"conversion_action",u"conversion_action_name",u"conversion_adjustment",u"date",u"geo_target_airport",u"geo_target_canton",u"geo_target_city",u"geo_target_country",u"geo_target_county",u"geo_target_district",u"geo_target_metro",u"geo_target_most_specific_location",u"geo_target_postal_code",u"geo_target_province",u"geo_target_region",u"geo_target_state",u"hotel_booking_window_days",u"hotel_center_id",u"hotel_check_in_date",u"hotel_city",u"hotel_class",u"hotel_country",u"hotel_length_of_stay",u"hotel_rate_rule_id",u"hotel_state",u"hour",u"interaction_on_this_extension",u"keyword",u"month",u"partner_hotel_id",u"product_aggregator_id",u"product_bidding_category_level1",u"product_bidding_category_level2",u"product_bidding_category_level3",u"product_bidding_category_level4",u"product_bidding_category_level5",u"product_brand",u"product_country",u"product_custom_attribute0",u"product_custom_attribute1",u"product_custom_attribute2",u"product_custom_attribute3",u"product_custom_attribute4",u"product_item_id",u"product_language",u"product_merchant_id",u"product_store_id",u"product_title",u"product_type_l1",u"product_type_l2",u"product_type_l3",u"product_type_l4",u"product_type_l5",u"quarter",u"webpage",u"week",u"year"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_network_type",u"click_type",u"conversion_action",u"conversion_action_category",u"conversion_action_name",u"conversion_adjustment",u"conversion_attribution_event_type",u"conversion_lag_bucket",u"conversion_or_adjustment_lag_bucket",u"date",u"day_of_week",u"device",u"external_conversion_source",u"geo_target_airport",u"geo_target_canton",u"geo_target_city",u"geo_target_country",u"geo_target_county",u"geo_target_district",u"geo_target_metro",u"geo_target_most_specific_location",u"geo_target_postal_code",u"geo_target_province",u"geo_target_region",u"geo_target_state",u"hotel_booking_window_days",u"hotel_center_id",u"hotel_check_in_date",u"hotel_check_in_day_of_week",u"hotel_city",u"hotel_class",u"hotel_country",u"hotel_date_selection_type",u"hotel_length_of_stay",u"hotel_price_bucket",u"hotel_rate_rule_id",u"hotel_rate_type",u"hotel_state",u"hour",u"interaction_on_this_extension",u"keyword",u"month",u"month_of_year",u"partner_hotel_id",u"placeholder_type",u"product_aggregator_id",u"product_bidding_category_level1",u"product_bidding_category_level2",u"product_bidding_category_level3",u"product_bidding_category_level4",u"product_bidding_category_level5",u"product_brand",u"product_channel",u"product_channel_exclusivity",u"product_condition",u"product_country",u"product_custom_attribute0",u"product_custom_attribute1",u"product_custom_attribute2",u"product_custom_attribute3",u"product_custom_attribute4",u"product_item_id",u"product_language",u"product_merchant_id",u"product_store_id",u"product_title",u"product_type_l1",u"product_type_l2",u"product_type_l3",u"product_type_l4",u"product_type_l5",u"quarter",u"search_engine_results_page_type",u"search_term_match_type",u"slot",u"webpage",u"week",u"year"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"conversion_action",b"conversion_action",u"conversion_action_name",b"conversion_action_name",u"conversion_adjustment",b"conversion_adjustment",u"date",b"date",u"geo_target_airport",b"geo_target_airport",u"geo_target_canton",b"geo_target_canton",u"geo_target_city",b"geo_target_city",u"geo_target_country",b"geo_target_country",u"geo_target_county",b"geo_target_county",u"geo_target_district",b"geo_target_district",u"geo_target_metro",b"geo_target_metro",u"geo_target_most_specific_location",b"geo_target_most_specific_location",u"geo_target_postal_code",b"geo_target_postal_code",u"geo_target_province",b"geo_target_province",u"geo_target_region",b"geo_target_region",u"geo_target_state",b"geo_target_state",u"hotel_booking_window_days",b"hotel_booking_window_days",u"hotel_center_id",b"hotel_center_id",u"hotel_check_in_date",b"hotel_check_in_date",u"hotel_city",b"hotel_city",u"hotel_class",b"hotel_class",u"hotel_country",b"hotel_country",u"hotel_length_of_stay",b"hotel_length_of_stay",u"hotel_rate_rule_id",b"hotel_rate_rule_id",u"hotel_state",b"hotel_state",u"hour",b"hour",u"interaction_on_this_extension",b"interaction_on_this_extension",u"keyword",b"keyword",u"month",b"month",u"partner_hotel_id",b"partner_hotel_id",u"product_aggregator_id",b"product_aggregator_id",u"product_bidding_category_level1",b"product_bidding_category_level1",u"product_bidding_category_level2",b"product_bidding_category_level2",u"product_bidding_category_level3",b"product_bidding_category_level3",u"product_bidding_category_level4",b"product_bidding_category_level4",u"product_bidding_category_level5",b"product_bidding_category_level5",u"product_brand",b"product_brand",u"product_country",b"product_country",u"product_custom_attribute0",b"product_custom_attribute0",u"product_custom_attribute1",b"product_custom_attribute1",u"product_custom_attribute2",b"product_custom_attribute2",u"product_custom_attribute3",b"product_custom_attribute3",u"product_custom_attribute4",b"product_custom_attribute4",u"product_item_id",b"product_item_id",u"product_language",b"product_language",u"product_merchant_id",b"product_merchant_id",u"product_store_id",b"product_store_id",u"product_title",b"product_title",u"product_type_l1",b"product_type_l1",u"product_type_l2",b"product_type_l2",u"product_type_l3",b"product_type_l3",u"product_type_l4",b"product_type_l4",u"product_type_l5",b"product_type_l5",u"quarter",b"quarter",u"webpage",b"webpage",u"week",b"week",u"year",b"year"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_network_type",b"ad_network_type",u"click_type",b"click_type",u"conversion_action",b"conversion_action",u"conversion_action_category",b"conversion_action_category",u"conversion_action_name",b"conversion_action_name",u"conversion_adjustment",b"conversion_adjustment",u"conversion_attribution_event_type",b"conversion_attribution_event_type",u"conversion_lag_bucket",b"conversion_lag_bucket",u"conversion_or_adjustment_lag_bucket",b"conversion_or_adjustment_lag_bucket",u"date",b"date",u"day_of_week",b"day_of_week",u"device",b"device",u"external_conversion_source",b"external_conversion_source",u"geo_target_airport",b"geo_target_airport",u"geo_target_canton",b"geo_target_canton",u"geo_target_city",b"geo_target_city",u"geo_target_country",b"geo_target_country",u"geo_target_county",b"geo_target_county",u"geo_target_district",b"geo_target_district",u"geo_target_metro",b"geo_target_metro",u"geo_target_most_specific_location",b"geo_target_most_specific_location",u"geo_target_postal_code",b"geo_target_postal_code",u"geo_target_province",b"geo_target_province",u"geo_target_region",b"geo_target_region",u"geo_target_state",b"geo_target_state",u"hotel_booking_window_days",b"hotel_booking_window_days",u"hotel_center_id",b"hotel_center_id",u"hotel_check_in_date",b"hotel_check_in_date",u"hotel_check_in_day_of_week",b"hotel_check_in_day_of_week",u"hotel_city",b"hotel_city",u"hotel_class",b"hotel_class",u"hotel_country",b"hotel_country",u"hotel_date_selection_type",b"hotel_date_selection_type",u"hotel_length_of_stay",b"hotel_length_of_stay",u"hotel_price_bucket",b"hotel_price_bucket",u"hotel_rate_rule_id",b"hotel_rate_rule_id",u"hotel_rate_type",b"hotel_rate_type",u"hotel_state",b"hotel_state",u"hour",b"hour",u"interaction_on_this_extension",b"interaction_on_this_extension",u"keyword",b"keyword",u"month",b"month",u"month_of_year",b"month_of_year",u"partner_hotel_id",b"partner_hotel_id",u"placeholder_type",b"placeholder_type",u"product_aggregator_id",b"product_aggregator_id",u"product_bidding_category_level1",b"product_bidding_category_level1",u"product_bidding_category_level2",b"product_bidding_category_level2",u"product_bidding_category_level3",b"product_bidding_category_level3",u"product_bidding_category_level4",b"product_bidding_category_level4",u"product_bidding_category_level5",b"product_bidding_category_level5",u"product_brand",b"product_brand",u"product_channel",b"product_channel",u"product_channel_exclusivity",b"product_channel_exclusivity",u"product_condition",b"product_condition",u"product_country",b"product_country",u"product_custom_attribute0",b"product_custom_attribute0",u"product_custom_attribute1",b"product_custom_attribute1",u"product_custom_attribute2",b"product_custom_attribute2",u"product_custom_attribute3",b"product_custom_attribute3",u"product_custom_attribute4",b"product_custom_attribute4",u"product_item_id",b"product_item_id",u"product_language",b"product_language",u"product_merchant_id",b"product_merchant_id",u"product_store_id",b"product_store_id",u"product_title",b"product_title",u"product_type_l1",b"product_type_l1",u"product_type_l2",b"product_type_l2",u"product_type_l3",b"product_type_l3",u"product_type_l4",b"product_type_l4",u"product_type_l5",b"product_type_l5",u"quarter",b"quarter",u"search_engine_results_page_type",b"search_engine_results_page_type",u"search_term_match_type",b"search_term_match_type",u"slot",b"slot",u"webpage",b"webpage",u"week",b"week",u"year",b"year"]) -> None: ...

class Keyword(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def ad_group_criterion(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def info(self) -> google___ads___googleads___v2___common___criteria_pb2___KeywordInfo: ...

    def __init__(self,
        *,
        ad_group_criterion : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        info : typing___Optional[google___ads___googleads___v2___common___criteria_pb2___KeywordInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Keyword: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group_criterion",u"info"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_criterion",u"info"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group_criterion",b"ad_group_criterion",u"info",b"info"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_criterion",b"ad_group_criterion",u"info",b"info"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ExtensionFeedItemErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ExtensionFeedItemError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ExtensionFeedItemErrorEnum.ExtensionFeedItemError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ExtensionFeedItemErrorEnum.ExtensionFeedItemError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ExtensionFeedItemErrorEnum.ExtensionFeedItemError]]: ...
        UNSPECIFIED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 0)
        UNKNOWN = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 1)
        VALUE_OUT_OF_RANGE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 2)
        URL_LIST_TOO_LONG = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 3)
        CANNOT_HAVE_RESTRICTION_ON_EMPTY_GEO_TARGETING = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 4)
        CANNOT_SET_WITH_FINAL_URLS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 5)
        CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 6)
        INVALID_PHONE_NUMBER = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 7)
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 8)
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 9)
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 10)
        DISALLOWED_NUMBER_TYPE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 11)
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 12)
        VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 13)
        INVALID_CALL_CONVERSION_ACTION = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 14)
        CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 15)
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 16)
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 17)
        INVALID_APP_ID = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 18)
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 19)
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 20)
        REVIEW_EXTENSION_SOURCE_INELIGIBLE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 21)
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 22)
        INCONSISTENT_CURRENCY_CODES = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 23)
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 24)
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 25)
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 26)
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 27)
        UNSUPPORTED_VALUE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 28)
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 29)
        INVALID_DEVICE_PREFERENCE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 30)
        INVALID_SCHEDULE_END = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 31)
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 32)
        INVALID_SNIPPETS_HEADER = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 33)
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 34)
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 35)
        CONFLICTING_CALL_CONVERSION_SETTINGS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 36)
        EXTENSION_TYPE_MISMATCH = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 37)
        EXTENSION_SUBTYPE_REQUIRED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 38)
        EXTENSION_TYPE_UNSUPPORTED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 39)
        CANNOT_OPERATE_ON_FEED_WITH_MULTIPLE_MAPPINGS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 40)
        CANNOT_OPERATE_ON_FEED_WITH_KEY_ATTRIBUTES = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 41)
        INVALID_PRICE_FORMAT = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 42)
        PROMOTION_INVALID_TIME = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 43)
        TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 44)
    UNSPECIFIED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 0)
    UNKNOWN = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 1)
    VALUE_OUT_OF_RANGE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 2)
    URL_LIST_TOO_LONG = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 3)
    CANNOT_HAVE_RESTRICTION_ON_EMPTY_GEO_TARGETING = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 4)
    CANNOT_SET_WITH_FINAL_URLS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 5)
    CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 6)
    INVALID_PHONE_NUMBER = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 7)
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 8)
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 9)
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 10)
    DISALLOWED_NUMBER_TYPE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 11)
    INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 12)
    VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 13)
    INVALID_CALL_CONVERSION_ACTION = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 14)
    CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 15)
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 16)
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 17)
    INVALID_APP_ID = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 18)
    QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 19)
    HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 20)
    REVIEW_EXTENSION_SOURCE_INELIGIBLE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 21)
    SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 22)
    INCONSISTENT_CURRENCY_CODES = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 23)
    PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 24)
    PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 25)
    PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 26)
    PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 27)
    UNSUPPORTED_VALUE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 28)
    UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 29)
    INVALID_DEVICE_PREFERENCE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 30)
    INVALID_SCHEDULE_END = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 31)
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 32)
    INVALID_SNIPPETS_HEADER = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 33)
    CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 34)
    PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 35)
    CONFLICTING_CALL_CONVERSION_SETTINGS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 36)
    EXTENSION_TYPE_MISMATCH = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 37)
    EXTENSION_SUBTYPE_REQUIRED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 38)
    EXTENSION_TYPE_UNSUPPORTED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 39)
    CANNOT_OPERATE_ON_FEED_WITH_MULTIPLE_MAPPINGS = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 40)
    CANNOT_OPERATE_ON_FEED_WITH_KEY_ATTRIBUTES = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 41)
    INVALID_PRICE_FORMAT = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 42)
    PROMOTION_INVALID_TIME = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 43)
    TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemError, 44)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ExtensionFeedItemErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
